@@ -70,6 +70,9 @@ sub display{	#this sub will display the page headers if needed
 			my $content = $self->_getContent();	#get the contents of the template
 			$self->content($content);
 		}
+		if($self->getError()){	#set the error code when needed
+			$self->code(500);
+		}
 		$output = "Status: " . $self->as_string();
 	}
 	print $output;
